package com.cardiff.client_project.controller.nursinghome;

import com.cardiff.client_project.pojo.dto.HospitalDTO;
import com.cardiff.client_project.service.NursingHomeService;
import com.cardiff.client_project.utils.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Slf4j
@RestController
@RequestMapping("/api/hospitals")
@CrossOrigin(origins = "*")
public class NursingHomeController {

    private final NursingHomeService nursingHomeService;

    @Autowired
    public NursingHomeController(NursingHomeService nursingHomeService) {
        this.nursingHomeService = nursingHomeService;
    }

    // READ - Get available beds
    @GetMapping("/available")
    public Result<List<HospitalDTO>> getAvailableBeds() {
        try {
            return nursingHomeService.getAvailableBeds();
        } catch (Exception e) {
            return Result.error("Error fetching available beds: " + e.getMessage());
        }
    }

    // CREATE - Add new hospital/bed data
    @PostMapping
    public Result<HospitalDTO> addHospital(@RequestBody HospitalDTO hospitalDTO) {
        try {
            return nursingHomeService.insertPatientInfo(hospitalDTO);
        } catch (Exception e) {
            return Result.error("Error adding hospital: " + e.getMessage());
        }
    }

    // UPDATE - Update bed count
    @PutMapping("/{hospitalId}/beds")
    public Result<String> updateBedCount(
            @PathVariable int hospitalId,
            @RequestParam int currentPatients) {
        try {
            return nursingHomeService.updateBedCount(hospitalId, currentPatients);
        } catch (Exception e) {
            return Result.error("Error updating bed count: " + e.getMessage());
        }
    }

    // DELETE - Delete hospital record
    @DeleteMapping("/{id}")
    public Result<String> deleteHospital(@PathVariable int id) {
        try {
            List<Integer> ids = List.of(id);
            return nursingHomeService.deletePatientById(ids);
        } catch (Exception e) {
            return Result.error("Error deleting hospital: " + e.getMessage());
        }
    }

    @GetMapping("/search")
    public Result<List<HospitalDTO>> searchHospitals(@RequestParam(required = false) String name) {
        try {
            log.info("Searching hospitals with name: {}", name);
            if (name == null || name.trim().isEmpty()) {
                return nursingHomeService.getAvailableBeds();
            }
            return nursingHomeService.searchHospitals(name.trim());
        } catch (Exception e) {
            log.error("Error searching hospitals: ", e);
            return Result.error("Error searching hospitals: " + e.getMessage());
        }
    }
}
